@@ -356,14 +356,14 @@ class LidarFrame:
             ]
 
     def to_json(
-        self, public_url: str = "", s3_upload: bool = True, project_name: str = ""
+        self, base_url: str = "", s3_upload: bool = True, project_name: str = ""
     ):
         """Return the frame data in json format following Scale data format: https://private-docs.scale.com/?python#sensor-fusion-lidar-annotatio.
 
         This will return the final data from the frame, this means cameras and points will be in world coordinates.
 
-        :param public_url: This url will concatenated with the image name, e.g.: `'%s/image-%s-%s.jpg' % (public_url, camera.id, frame.id)`
-        :type public_url: str
+        :param base_url: This url will concatenated with the image name, e.g.: `'%s/image-%s-%s.jpg' % (base_url, camera.id, frame.id)`
+        :type base_url: str
         :returns: Frame object as a JSON formatted stream
         :rtype: str
 
@@ -378,7 +378,7 @@ class LidarFrame:
 
             D = camera.D
 
-            image_url = "%s/image-%s-%s.jpg" % (public_url, camera.id, self.id)
+            image_url = "%s/image-%s-%s.jpg" % (base_url, camera.id, self.id)
             if not s3_upload:
                 image_url = self.images[camera.id].scale_file_upload(project_name)
 
@@ -456,18 +456,18 @@ class LidarFrame:
 
         return out
 
-    def save(self, path: str, public_url: str = ""):
+    def save(self, path: str, base_url: str = ""):
         """Save frame object in a json file
 
         :param path: Path in which the frame data should be saved
         :type path: str
-        :param public_url: This url will concatenated with the image name, e.g.: `'%s/image-%s-%s.jpg' % (public_url, camera.id, frame.id)`
-        :type public_url: str
+        :param base_url: This url will concatenated with the image name, e.g.: `'%s/image-%s-%s.jpg' % (base_url, camera.id, frame.id)`
+        :type base_url: str
 
         """
         # Save frame
         with open(os.path.join(path, "frame-%s.json" % self.id), "w") as file:
-            file.write(self.to_json(public_url))
+            file.write(self.to_json(base_url))
 
         # Save images
         for camera_id, image in self.images.items():
@@ -483,11 +483,11 @@ class LidarFrame:
 
         """
         # print(f'Uploading frame {self.id}...')
-        public_url = f"s3://{bucket}/{path}"
+        base_url = f"s3://{bucket}/{path}"
 
         # Upload frame json file
         s3_smart_upload(
-            fileobj=BytesIO(bytes(self.to_json(public_url), encoding="utf-8")),
+            fileobj=BytesIO(bytes(self.to_json(base_url), encoding="utf-8")),
             bucket=bucket,
             key=f"{path}/frame-{self.id}.json",
             content_type="application/json",
@@ -505,6 +505,7 @@ class LidarFrame:
 
         """
 
+        print(f"Uploading frame {self.id} to Scale file")
         fileobj = BytesIO(
             bytes(
                 self.to_json(s3_upload=False, project_name=project_name),
